@@ -9,9 +9,9 @@ from .generated import TSAArchives_sos_pb2 as TSAArchives_sos
 from .generated import TSACommandArchives_sos_pb2 as TSACommandArchives_sos
 from .generated import TSCEArchives_pb2 as TSCEArchives
 from .generated import TSCH3DArchives_pb2 as TSCH3DArchives
+from .generated import TSCHArchives_pb2 as TSCHArchives
 from .generated import TSCHArchives_Common_pb2 as TSCHArchives_Common
 from .generated import TSCHArchives_GEN_pb2 as TSCHArchives_GEN
-from .generated import TSCHArchives_pb2 as TSCHArchives
 from .generated import TSCHArchives_sos_pb2 as TSCHArchives_sos
 from .generated import TSCHCommandArchives_pb2 as TSCHCommandArchives
 from .generated import TSCHPreUFFArchives_pb2 as TSCHPreUFFArchives
@@ -19,6 +19,7 @@ from .generated import TSDArchives_pb2 as TSDArchives
 from .generated import TSDArchives_sos_pb2 as TSDArchives_sos
 from .generated import TSDCommandArchives_pb2 as TSDCommandArchives
 from .generated import TSKArchives_pb2 as TSKArchives
+from .generated import TSKArchives_sos_pb2 as TSKArchives_sos
 from .generated import TSPArchiveMessages_pb2 as TSPArchiveMessages
 from .generated import TSPDatabaseMessages_pb2 as TSPDatabaseMessages
 from .generated import TSPMessages_pb2 as TSPMessages
@@ -53,6 +54,7 @@ PROTO_FILES = [
     TSDArchives_sos,
     TSDCommandArchives,
     TSKArchives,
+    TSKArchives_sos,
     TSPArchiveMessages,
     TSPDatabaseMessages,
     TSPMessages,
@@ -92,6 +94,7 @@ TSPRegistryMapping = {
     "23": "KN.DesktopUILayoutArchive",
     "24": "KN.CanvasSelectionArchive",
     "25": "KN.SlideCollectionSelectionArchive",
+    "26": "KN.MotionBackgroundStyleArchive",
     "100": "KN.CommandBuildSetValueArchive",
     "101": "KN.CommandShowInsertSlideArchive",
     "102": "KN.CommandShowMoveSlideArchive",
@@ -164,6 +167,8 @@ TSPRegistryMapping = {
     "190": "KN.CommandLiveVideoStyleSetValue",
     "191": "KN.CommandThemeAddLiveVideoSource",
     "192": "KN.CommandThemeRemoveLiveVideoSource",
+    "194": "KN.CommandMotionBackgroundStyleSetValueArchive",
+    "195": "KN.CommandMotionBackgroundStyleUpdatePosterFrameDataArchive",
     "200": "TSK.DocumentArchive",
     "201": "TSK.LocalCommandHistory",
     "202": "TSK.CommandGroupArchive",
@@ -304,7 +309,6 @@ TSPRegistryMapping = {
     "2119": "TSWP.UpdateDateTimeFieldCommandArchive",
     "2120": "TSWP.ModifyTOCSettingsBaseCommandArchive",
     "2121": "TSWP.ModifyTOCSettingsForTOCInfoCommandArchive",
-    "2122": "TSWP.ModifyTOCSettingsPresetForThemeCommandArchive",
     "2123": "TSWP.SetObjectPropertiesCommandArchive",
     "2124": "TSWP.UpdateFlowInfoCommandArchive",
     "2125": "TSWP.AddFlowInfoCommandArchive",
@@ -648,6 +652,8 @@ TSPRegistryMapping = {
     "6379": "TST.CommandRewritePivotOwnerFormulasArchive",
     "6380": "TST.CommandRewriteTrackedReferencesArchive",
     "6381": "TST.CommandExtendTableIDHistoryArchive",
+    "6382": "TST.GroupByArchive.AggregatorArchive",
+    "6383": "TST.GroupByArchive.GroupNodeArchive",
     "10011": "TSWP.SectionPlaceholderArchive",
     "10020": "TSWP.ShapeSelectionTransformerArchive",
     "10021": "TSWP.SelectionTransformerArchive",
